@@ -1,4 +1,4 @@
-/*	$Id: kcgi.h,v 1.84 2016/01/07 07:31:53 kristaps Exp $ */
+/*	$Id: kcgi.h,v 1.87 2016/03/10 05:45:21 kristaps Exp $ */
 /*
  * Copyright (c) 2012, 2014, 2015, 2016 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -17,6 +17,21 @@
 #ifndef KCGI_H
 #define KCGI_H
 
+#if !defined(__BEGIN_DECLS)
+#  ifdef __cplusplus
+#  define       __BEGIN_DECLS           extern "C" {
+#  else
+#  define       __BEGIN_DECLS
+#  endif
+#endif
+#if !defined(__END_DECLS)
+#  ifdef __cplusplus
+#  define       __END_DECLS             }
+#  else
+#  define       __END_DECLS
+#  endif
+#endif
+
 /*
  * All of the public functions, variables, and structures in this header
  * file are described in kcgi(3).
@@ -410,6 +425,10 @@ struct	kreq {
 	void			 *arg; 
 };
 
+struct	kopts {
+	ssize_t		  	  sndbufsz;
+};
+
 struct	ktemplate {
 	const char *const	 *key;
 	size_t		 	  keysz;
@@ -451,7 +470,7 @@ enum kcgi_err	 khttp_parsex(struct kreq *, const struct kmimemap *,
 			const struct kvalid *, size_t,
 			const char *const *, size_t,
 			size_t, size_t, void *, void (*)(void *),
-			unsigned int);
+			unsigned int, const struct kopts *);
 void		 khttp_putc(struct kreq *, int);
 void		 khttp_puts(struct kreq *, const char *);
 int		 khttp_template(struct kreq *, 
@@ -466,6 +485,8 @@ void		 khttp_write(struct kreq *, const char *, size_t);
 
 int		 khttpdigest_validate(const struct kreq *, 
 			const char *);
+int		 khttpdigest_validatehash(const struct kreq *, 
+			const char *);
 int		 khttpbasic_validate(const struct kreq *, 
 			const char *, const char *);
 
@@ -487,7 +508,8 @@ enum kcgi_err	 khttp_fcgi_initx(struct kfcgi **,
 			const struct kvalid *, size_t, 
 			const struct kmimemap *, size_t,
 			const char *const *, size_t, size_t,
-			void *, void (*)(void *), unsigned int);
+			void *, void (*)(void *), unsigned int,
+			const struct kopts *);
 enum kcgi_err	 khttp_fcgi_free(struct kfcgi *);
 void		 khttp_fcgi_child_free(struct kfcgi *);
 int		 khttp_fcgi_test(void);
