@@ -1,4 +1,4 @@
-/*	$Id: kcgihtml.h,v 1.4 2015/04/27 16:27:24 kristaps Exp $ */
+/*	$Id: kcgihtml.h,v 1.5 2016/03/10 05:45:21 kristaps Exp $ */
 /*
  * Copyright (c) 2012, 2014, 2015 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -17,6 +17,21 @@
 #ifndef KCGIHTML_H
 #define KCGIHTML_H
 
+#if !defined(__BEGIN_DECLS)
+#  ifdef __cplusplus
+#  define       __BEGIN_DECLS           extern "C" {
+#  else
+#  define       __BEGIN_DECLS
+#  endif
+#endif
+#if !defined(__END_DECLS)
+#  ifdef __cplusplus
+#  define       __END_DECLS             }
+#  else
+#  define       __END_DECLS
+#  endif
+#endif
+
 enum	kentity {
 	KENTITY_AElig,
 	KENTITY_Aacute,
