@@ -1,4 +1,4 @@
-/*	$Id: sample-fcgi.c,v 1.9 2015/10/01 00:27:17 kristaps Exp $ */
+/*	$Id: sample-fcgi.c,v 1.10 2016/03/12 08:54:36 kristaps Exp $ */
 /*
  * Copyright (c) 2015 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -52,10 +52,14 @@ main(int argc, char *argv[])
 	for (rc = 0;;) {
 		er = khttp_fcgi_parse(fcgi, &req);
 		if (KCGI_HUP == er) {
+			fprintf(stderr, "Terminate: "
+				"parse hangup\n");
 			rc = 1;
 			khttp_free(&req);
 			break;
 		} else if (KCGI_OK != er) {
+			fprintf(stderr, "Terminate: "
+				"parse error: %d\n", er);
 			khttp_free(&req);
 			break;
 		}
