@@ -1,4 +1,4 @@
-/*	$Id: sample.c,v 1.39 2015/07/07 20:30:13 kristaps Exp $ */
+/*	$Id: sample.c,v 1.44 2016/03/15 11:36:20 kristaps Exp $ */
 /*
  * Copyright (c) 2014, 2015 Kristaps Dzonsons <kristaps@bsd.lv>
  *
@@ -14,9 +14,11 @@
  * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
+#include <stdio.h>
 #include <stdint.h>
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
 
 #include "kcgi.h"
 #include "kcgihtml.h"
@@ -30,6 +32,7 @@
 enum	page {
 	PAGE_INDEX,
 	PAGE_TEMPLATE,
+	PAGE_SENDDATA,
 	PAGE__MAX
 };
 
@@ -41,6 +44,8 @@ enum	page {
 enum	key {
 	KEY_INTEGER, 
 	KEY_FILE,
+	KEY_PAGECOUNT,
+	KEY_PAGESIZE,
 	KEY__MAX
 };
 
@@ -63,17 +68,21 @@ enum	templ {
  */
 typedef	void (*disp)(struct kreq *);
 
+static void senddata(struct kreq *);
 static void sendindex(struct kreq *);
 static void sendtemplate(struct kreq *);
 
 static const disp disps[PAGE__MAX] = {
 	sendindex, /* PAGE_INDEX */
 	sendtemplate, /* PAGE_TEMPLATE */
+	senddata, /* PAGE_SENDDATA */
 };
 
 static const struct kvalid keys[KEY__MAX] = {
 	{ kvalid_int, "integer" }, /* KEY_INTEGER */
 	{ NULL, "file" }, /* KEY_FILE */
+	{ kvalid_uint, "count" }, /* KEY_PAGECOUNT */
+	{ kvalid_uint, "size" }, /* KEY_PAGESIZE */
 };
 
 /*
@@ -90,7 +99,8 @@ static const char *const templs[TEMPL__MAX] = {
  */
 static const char *const pages[PAGE__MAX] = {
 	"index", /* PAGE_INDEX */
-	"template" /* PAGE_TEMPLATE */
+	"template", /* PAGE_TEMPLATE */
+	"senddata" /* PAGE_SENDDATA */
 };
 
 /*
@@ -161,6 +171,47 @@ sendtemplate(struct kreq *req)
 	khttp_template(req, &t, "template.xml");
 }
 
+/*
+ * Send a random amount of data.
+ * This tests how well the application performs under load.
+ * We accept two optional parameters: page size and count.
+ * Page count is the number of times we flush a page (with the given
+ * size) to the wire.
+ */
+static void
+senddata(struct kreq *req)
+{
+	int64_t	  i, j, nm, sz;
+	char	 *buf;
+
+	nm = 1024 * 1024;
+	if (NULL != req->fieldmap[KEY_PAGECOUNT])
+		nm = req->fieldmap[KEY_PAGECOUNT]->parsed.i;
+	if (0 == nm)
+		nm = 1;
+
+	sz = 1;
+	if (NULL != req->fieldmap[KEY_PAGESIZE])
+		sz = req->fieldmap[KEY_PAGESIZE]->parsed.i;
+	if (0 == sz || (uint64_t)sz > SIZE_MAX)
+		sz = 1;
+	
+	buf = kmalloc(sz);
+
+	resp_open(req, KHTTP_200);
+	for (i = 0; i < nm; i++) {
+		for (j = 0; j < sz; j++)
+#ifndef __linux__
+			buf[j] = 65 + arc4random_uniform(24);
+#else
+			buf[j] = 65 + (random() % 24);
+#endif
+		khttp_write(req, buf, sz);
+	}
+
+	free(buf);
+}
+
 /*
  * Send the "index" page.
  * This demonstrates how to use GET and POST forms and building with the
@@ -234,11 +285,17 @@ int
 main(void)
 {
 	struct kreq	 r;
+	enum kcgi_err	 er;
 
 	/* Set up our main HTTP context. */
-	if (KCGI_OK != khttp_parse(&r, keys, KEY__MAX, 
-		pages, PAGE__MAX, PAGE_INDEX))
+	er = khttp_parse(&r, keys, KEY__MAX, 
+		pages, PAGE__MAX, PAGE_INDEX);
+
+	if (KCGI_OK != er) {
+		fprintf(stderr, "Terminate: parse error: %d\n", er);
+		khttp_free(&r);
 		return(EXIT_FAILURE);
+	}
 
 	if (KMETHOD_OPTIONS == r.method) {
 		/* Indicate that we accept GET, POST, and PUT. */
